@@ -4,36 +4,39 @@ use warnings;
 use strict;
 use Carp;
 use vars ('$AUTOLOAD');
-use Storable ();
+
 
 =head1 NAME
 
-Text::FixedWidth - Easy OO manipulation of fixed width text files
+Text::FixedWidth - Easy OO manipulation of fixed width text files.
+
+=head1 VERSION
+
+Version 0.02
 
 =cut
 
-our $VERSION = '0.07_01';
+our $VERSION = '0.02';
+
 
 =head1 SYNOPSIS
 
    use Text::FixedWidth;
-
-   my $fw = new Text::FixedWidth;
+   my $fw = new Text::FixedWidth, "new()");
    $fw->set_attributes(qw(
       fname            undef  %10s
       lname            undef  %-10s
       points           0      %04d
-   ));
-
-   $fw->parse(string => '       JayHannah    0003');
-   $fw->get_fname;               # Jay
-   $fw->get_lname;               # Hannah
-   $fw->get_points;              # 0003
+   );
+   $fw->parse(message => "       JayHannah    0003");
+   print $fw->get_fname;   # Jay
+   print $fw->get_lname;   # Hannah
+   print $fw->get_points;  # 0003
 
    $fw->set_fname('Chuck');
    $fw->set_lname('Norris');
    $fw->set_points(17);
-   $fw->string;                  # '     ChuckNorris    0017'
+   print $fw->string;      #  '     ChuckNorris    0017'
 
 If you're familiar with printf formats, then this class should make processing
 fixed width files trivial.
@@ -49,7 +52,7 @@ care about.
 
 =head2 new
 
-Constructor. Does nothing fancy.
+Constructor. See SYNOPSIS.
 
 =cut
 
@@ -69,7 +72,7 @@ Pass in arguments in sets of 3 and we'll set up attributes for you.
 
 The first argument is the attribute name. The second argument is the default
 value we should use until told otherwise. The third is the printf format we should
-use to read and write this attribute from/to a string.
+use to read or write this attribute from/to a string.
 
   $fw->set_attributes(qw(
     fname            undef  %10s
@@ -104,35 +107,33 @@ sub set_attributes {
 
 =head2 parse
 
-Parses the string you hand in. Sets each attribute to the value it finds in the string.
+Parse a string. Set each attribute to the value listed in the string.
 
-  $fw->parse(string => '       JayHannah    0003');
+  $fw->parse(message => "       JayHannah    0003");
 
 =cut
 
 sub parse {
    my ($self, %args) = @_;
 
-   die ref($self).":Please provide a string argument" if (!$args{string});
-   my $string = $args{string};
-
-   $self = $self->clone if $args{clone};
+   die ref($self).":Please provide a message argument" if (!$args{message});
+   my $message = $args{message};
 
    my $offset = 0;
    foreach (@{$self->{_attribute_order}}) {
       my $length = $self->{_attributes}{$_}{length};
-      $self->{_attributes}{$_}{value}  = substr $string, $offset, $length;
+      $self->{_attributes}{$_}{value}  = substr $message, $offset, $length;
       $offset += $length;
    }
 
-   return $args{clone}? $self : 1;
+   return 1;
 }
 
 
 =head2 string
 
 Dump the object to a string. Walks each attribute in order and outputs each in the
-format that was specified during set_attributes().
+format that was specified during set_attributes.
 
   print $fw->string;      #  '     ChuckNorris    0017'
 
@@ -142,39 +143,18 @@ sub string {
    my ($self) = @_;
 
    my ($value, $length, $sprintf, $return);
-   foreach my $att (@{$self->{_attribute_order}}) {
-      $value   = $self->{_attributes}{$att}{value};
-      $length  = $self->{_attributes}{$att}{length};
-      $sprintf = $self->{_attributes}{$att}{sprintf};
+   foreach (@{$self->{_attribute_order}}) {
+      $value   = $self->{_attributes}{$_}{value};
+      $length  = $self->{_attributes}{$_}{length};
+      $sprintf = $self->{_attributes}{$_}{sprintf};
 
       if (defined ($value) and length($value) > $length) {
-         warn "string() error! " . ref($self) . " length of attribute '$att' cannot exceed '$length', but it does. Please shorten the value '$value'";
+         warn "string() error! Length of $_ cannot exceed $length, but it does. Please shorten the value '$value'";
          return 0;
       }
-      if (not defined $value) {
-         $value = '';
-      }
-      unless ($sprintf) {
-         warn "string() error! " . ref($self) . " sprintf not set on attribute $att. Using '%s'";
-         $sprintf = '%s';
-      }
-
-      my $tmp;
-      if (
-         $sprintf =~ /\%\d*[duoxefgXEGbB]/ && (       # perldoc -f sprintf
-            (not defined $value) ||
-            $value eq "" ||
-            $value !~ /^(\d+\.?\d*|\.\d+)$/        # match valid number
-         )
-      ) {
-         $value = '' if (not defined $value);
-         warn "string() warning: " . ref($self) . " attribute '$att' contains '$value' which is not numeric, yet the sprintf '$sprintf' appears to be numeric. Using 0";
-         $value = 0;
-      }
-      $tmp = sprintf($sprintf, (defined $value ? $value : ""));
-
+      my $tmp = sprintf($sprintf, $value);
       if (length($tmp) != $length) {
-         die "string() error: " . ref($self) . " is loaded with an sprintf format which returns a string that is NOT the correct length! Please correct the class! The error occured on attribute '$att' converting value '$value' via sprintf '$sprintf', which is '$tmp', which is not '$length' characters long";
+         die "Ack! " . ref($self) . " is loaded with an sprintf format which returns a string that is NOT the correct length! Please correct the class! The error occured on attribute '$_' converting value '$value' via sprintf '$sprintf', which is '$tmp', which is not '$length' characters long";
       }
 
       $return .= $tmp;
@@ -200,39 +180,11 @@ sub auto_truncate {
    my ($self, @attrs) = @_;
    $self->{_auto_truncate} = {};
    foreach my $attr (@attrs) {
-      unless ($self->{_attributes}{$attr}) {
-         carp "Can't auto_truncate attribute '$attr' because that attribute does not exist";
-         next;
-      }
       $self->{_auto_truncate}->{$attr} = 1;
    }
    return 1;
 }
 
-=head2 clone
-
-Provides a clone of a Text::FixedWidth object. If available it will attempt
-to use L<Clone::Fast> or L<Clone::More> falling back on L<Storable/dclone>.
-
-   my $fw_copy = $fw->clone;
-
-This method is most useful when being called from with in the L</parse> method.
-
-   while( my $row = $fw->parse( clone => 1, string => $str ) ) {
-      print $row->foobar;
-   }
-
-See L</parse> for further information.
-
-=cut
-
-sub clone {
-   my $self = shift;
-   return Storable::dclone($self);
-}
-
-
-
 
 sub DESTROY { }
 
@@ -262,15 +214,15 @@ sub AUTOLOAD {
       my $val  = $_[1];
       croak "Can't set_$att(). No such attribute: $att" unless (defined $self->{_attributes}{$att});
       if (defined $self->{_attributes}{$att}) {
-        if (defined $val && length($val) > $self->{_attributes}{$att}{length}) {
-          if ($self->{_auto_truncate}{$att}) {
-            $val = substr($val, 0, $self->{_attributes}{$att}{length});
-            $self->{_attributes}{$att}{value} = $val;
-          } else {
-            carp "Can't set_$att('$val'). Value must be " .
-              $self->{_attributes}{$att}{length} . " characters or shorter";
-            return undef;
-          }
+        if (length($val) > $self->{_attributes}{$att}{length}) {
+           if ($self->{_auto_truncate}{$att}) {
+              $val = substr($val, 0, $self->{_attributes}{$att}{length});
+              $self->{_attributes}{$att}{value} = $val;
+           } else {
+              carp "Can't set_$att('$val'). Value must be " .
+                 $self->{_attributes}{$att}{length} . " characters or shorter";
+              return undef;
+           }
         }
         $self->{_attributes}{$att}{value} = $val;
         return 1;
@@ -287,7 +239,7 @@ sub AUTOLOAD {
 
 =head1 ALTERNATIVES
 
-Other modules that may do similar things:
+Other modules that do similar things that you might like:
 L<Parse::FixedLength>,
 L<Text::FixedLength>,
 L<Data::FixedFormat>,
@@ -295,7 +247,7 @@ L<AnyData::Format::Fixed>
 
 =head1 AUTHOR
 
-Jay Hannah, C<< <jay at jays.net> >>, http://jays.net
+Jay Hannah, C<< <jay at jays.net> >>
 
 =head1 BUGS
 
@@ -329,16 +281,12 @@ L<http://cpanratings.perl.org/d/Text-FixedWidth>
 
 L<http://search.cpan.org/dist/Text-FixedWidth>
 
-=item * Source code
-
-L<http://github.com/jhannah/text-fixedwidth>
-
 =back
 
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008-2009 Jay Hannah, all rights reserved.
+Copyright 2008 Jay Hannah, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
